==> mingw-w64-c%2B%2Butilities-4.9.1-1-any.pkg.tar.xz: usr/x86_64-w64-mingw32/share/c++utilities/cmake/c++utilitiesConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# provide meta-data
set(c++utilities_varname "CPP_UTILITIES")
set(c++utilities_static_varname "CPP_UTILITIES")
set(CPP_UTILITIES_DISPLAY_NAME "C++ Utilities")
set(CPP_UTILITIES_AUTHOR "Martchus")
set(CPP_UTILITIES_VERSION "4.9.1")
set(CPP_UTILITIES_VERSION_MAJOR "4")
set(CPP_UTILITIES_VERSION_MINOR "9")
set(CPP_UTILITIES_VERSION_PATCH "1")
set(CPP_UTILITIES_GIT_REV_COUNT "")
set(CPP_UTILITIES_GIT_LAST_COMMIT_ID "")
set(CPP_UTILITIES_URL "https://github.com/Martchus/c++utilities")
set(CPP_UTILITIES_DESCRIPTION "Common C++ classes and routines used by my applications such as argument parser, IO and conversion utilities")

# define general config
set(CPP_UTILITIES_IS_HEADER_ONLY NO)
set(CPP_UTILITIES_HAS_SHARED_LIB ON)
set(CPP_UTILITIES_HAS_STATIC_LIB ON)
set(CPP_UTILITIES_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(CPP_UTILITIES_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin")
set(CPP_UTILITIES_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(CPP_UTILITIES_MODULE_DIRS "${PACKAGE_PREFIX_DIR}/share/c++utilities/cmake/modules")
set(CPP_UTILITIES_CONFIG_DIRS "${PACKAGE_PREFIX_DIR}/share/c++utilities/cmake")
set(CPP_UTILITIES_PRIVATE_QT_MODULES "")
set(CPP_UTILITIES_PRIVATE_KF_MODULES "")
set(CPP_UTILITIES_PUBLIC_QT_MODULES "")
set(CPP_UTILITIES_PUBLIC_KF_MODULES "")
set(CPP_UTILITIES_HAS_QT_TRANSLATION_FILES )
set(CPP_UTILITIES_QT_RESOURCES )

# define shared library config
if(CPP_UTILITIES_HAS_SHARED_LIB)
    set(CPP_UTILITIES_SHARED_LIB "c++utilities")
    set(CPP_UTILITIES_SHARED_LIB_DEPENDS )
    set(CPP_UTILITIES_SHARED_LIB_COMPILE_DEFINITIONS CPP_UTILITIES_USE_NATIVE_FILE_BUFFER)
    set(PC_PKG_SHARED_c++utilities "c++utilities")
    if(NOT TARGET "${CPP_UTILITIES_SHARED_LIB}")
        include("${CMAKE_CURRENT_LIST_DIR}/c++utilitiesSharedTargets.cmake")
    endif()
endif()

# define static library config
if(CPP_UTILITIES_HAS_STATIC_LIB)
    set(CPP_UTILITIES_STATIC_LIB "c++utilities_static")
    set(CPP_UTILITIES_STATIC_LIB_DEPENDS  /usr/x86_64-w64-mingw32/lib/libiconv.a)
    set(CPP_UTILITIES_STATIC_LIB_COMPILE_DEFINITIONS CPP_UTILITIES_USE_NATIVE_FILE_BUFFER;CPP_UTILITIES_STATIC)
    set(PC_PKG_STATIC_c++utilities_static "c++utilities_static")
    if(NOT TARGET "${CPP_UTILITIES_STATIC_LIB}")
        include("${CMAKE_CURRENT_LIST_DIR}/c++utilitiesStaticTargets.cmake")
    endif()
endif()

# set default target: prefer shared lib over static lib
if(CPP_UTILITIES_HAS_SHARED_LIB)
    set(CPP_UTILITIES_LIB "c++utilities")
else()
    set(CPP_UTILITIES_LIB "c++utilities_static")
endif()

# define macro to ease use of library
macro(use_CPP_UTILITIES)
    # make CMake modules of the project available
    list(APPEND CMAKE_MODULE_PATH ${CPP_UTILITIES_MODULE_DIRS})
    # link against library (also "link" against header-only libs to get compile defs and interface link libs)
    link_directories(${CPP_UTILITIES_LIB_DIR})
    include(3rdParty)
    if(NOT ARGV0)
        set(CPP_UTILITIES_LINKAGE AUTO_LINKAGE)
    else()
        set(CPP_UTILITIES_LINKAGE "${ARG0}")
    endif()
    link_against_library(CPP_UTILITIES "${CPP_UTILITIES_LINKAGE}" REQUIRED)
    # add required Qt and KF modules
    list(APPEND IMPORTED_QT_MODULES ${CPP_UTILITIES_PUBLIC_QT_MODULES})
    list(APPEND IMPORTED_KF_MODULES ${CPP_UTILITIES_PUBLIC_KF_MODULES})
    # add required translations to APP_SPECIFIC_QT_TRANSLATION_FILES_ARRAY
    if(CPP_UTILITIES_HAS_QT_TRANSLATION_FILES)
        list(APPEND APP_SPECIFIC_QT_TRANSLATION_FILES c++utilities)
    endif()
    # ensure Qt resources of static libs are loaded
    if(USE_STATIC_CPP_UTILITIES AND CPP_UTILITIES_QT_RESOURCES)
        message(STATUS "Adding ${CPP_UTILITIES_QT_RESOURCES} to LIBRARIES_QT_RESOURCES for ${META_PROJECT_NAME}.")
        list(APPEND LIBRARIES_QT_RESOURCES ${CPP_UTILITIES_QT_RESOURCES})
    endif()
endmacro()

==> mingw-w64-c%2B%2Butilities-4.9.2-1-any.pkg.tar.xz: usr/x86_64-w64-mingw32/share/c++utilities/cmake/c++utilitiesConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# provide meta-data
set(c++utilities_varname "CPP_UTILITIES")
set(c++utilities_static_varname "CPP_UTILITIES")
set(CPP_UTILITIES_DISPLAY_NAME "C++ Utilities")
set(CPP_UTILITIES_AUTHOR "Martchus")
set(CPP_UTILITIES_VERSION "4.9.2")
set(CPP_UTILITIES_VERSION_MAJOR "4")
set(CPP_UTILITIES_VERSION_MINOR "9")
set(CPP_UTILITIES_VERSION_PATCH "2")
set(CPP_UTILITIES_GIT_REV_COUNT "")
set(CPP_UTILITIES_GIT_LAST_COMMIT_ID "")
set(CPP_UTILITIES_URL "https://github.com/Martchus/c++utilities")
set(CPP_UTILITIES_DESCRIPTION "Common C++ classes and routines used by my applications such as argument parser, IO and conversion utilities")

# define general config
set(CPP_UTILITIES_IS_HEADER_ONLY NO)
set(CPP_UTILITIES_HAS_SHARED_LIB ON)
set(CPP_UTILITIES_HAS_STATIC_LIB ON)
set(CPP_UTILITIES_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(CPP_UTILITIES_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin")
set(CPP_UTILITIES_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(CPP_UTILITIES_MODULE_DIRS "${PACKAGE_PREFIX_DIR}/share/c++utilities/cmake/modules")
set(CPP_UTILITIES_CONFIG_DIRS "${PACKAGE_PREFIX_DIR}/share/c++utilities/cmake")
set(CPP_UTILITIES_PRIVATE_QT_MODULES "")
set(CPP_UTILITIES_PRIVATE_KF_MODULES "")
set(CPP_UTILITIES_PUBLIC_QT_MODULES "")
set(CPP_UTILITIES_PUBLIC_KF_MODULES "")
set(CPP_UTILITIES_HAS_QT_TRANSLATION_FILES )
set(CPP_UTILITIES_QT_RESOURCES )

# define shared library config
if(CPP_UTILITIES_HAS_SHARED_LIB)
    set(CPP_UTILITIES_SHARED_LIB "c++utilities")
    set(CPP_UTILITIES_SHARED_LIB_DEPENDS )
    set(CPP_UTILITIES_SHARED_LIB_COMPILE_DEFINITIONS CPP_UTILITIES_USE_NATIVE_FILE_BUFFER)
    set(PC_PKG_SHARED_c++utilities "c++utilities")
    if(NOT TARGET "${CPP_UTILITIES_SHARED_LIB}")
        include("${CMAKE_CURRENT_LIST_DIR}/c++utilitiesSharedTargets.cmake")
    endif()
endif()

# define static library config
if(CPP_UTILITIES_HAS_STATIC_LIB)
    set(CPP_UTILITIES_STATIC_LIB "c++utilities_static")
    set(CPP_UTILITIES_STATIC_LIB_DEPENDS  /usr/x86_64-w64-mingw32/lib/libiconv.a)
    set(CPP_UTILITIES_STATIC_LIB_COMPILE_DEFINITIONS CPP_UTILITIES_USE_NATIVE_FILE_BUFFER;CPP_UTILITIES_STATIC)
    set(PC_PKG_STATIC_c++utilities_static "c++utilities_static")
    if(NOT TARGET "${CPP_UTILITIES_STATIC_LIB}")
        include("${CMAKE_CURRENT_LIST_DIR}/c++utilitiesStaticTargets.cmake")
    endif()
endif()

# set default target: prefer shared lib over static lib
if(CPP_UTILITIES_HAS_SHARED_LIB)
    set(CPP_UTILITIES_LIB "c++utilities")
else()
    set(CPP_UTILITIES_LIB "c++utilities_static")
endif()

# define macro to ease use of library
macro(use_CPP_UTILITIES)
    # make CMake modules of the project available
    list(APPEND CMAKE_MODULE_PATH ${CPP_UTILITIES_MODULE_DIRS})
    # link against library (also "link" against header-only libs to get compile defs and interface link libs)
    link_directories(${CPP_UTILITIES_LIB_DIR})
    include(3rdParty)
    if(NOT ARGV0)
        set(CPP_UTILITIES_LINKAGE AUTO_LINKAGE)
    else()
        set(CPP_UTILITIES_LINKAGE "${ARG0}")
    endif()
    link_against_library(CPP_UTILITIES "${CPP_UTILITIES_LINKAGE}" REQUIRED)
    # add required Qt and KF modules
    list(APPEND IMPORTED_QT_MODULES
        ${CPP_UTILITIES_PUBLIC_QT_MODULES}
        ${CPP_UTILITIES_PRIVATE_QT_MODULES}
    )
    list(APPEND IMPORTED_KF_MODULES
        ${CPP_UTILITIES_PUBLIC_KF_MODULES}
        ${CPP_UTILITIES_PRIVATE_KF_MODULES}
    )
    # add required translations to APP_SPECIFIC_QT_TRANSLATION_FILES_ARRAY
    if(CPP_UTILITIES_HAS_QT_TRANSLATION_FILES)
        list(APPEND APP_SPECIFIC_QT_TRANSLATION_FILES c++utilities)
    endif()
endmacro()
